#
# spec file for package nemesis
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2018-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nemesis
Version:        1.8
Release:        1.9
Summary:        TCP/IP Packet Injection Suite
License:        BSD-4-Clause
Group:          Productivity/Networking/Diagnostic
URL:            http://troglobit.com/projects/nemesis/
#Git-Clone:     https://github.com/troglobit/nemesis
Source:         https://github.com/troglobit/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libnet-devel

%description
A commandline-based IP stack for Linux. The suite is broken down by
protocol and allows for scripting of injected packet streams from
shell scripts.

Key features:
 * support for ARP, DNS, ICMP, IGMP, OSPF, RIP, TCP, UDP protocols
 * layer 2 or layer 3 injection
 * packet payload from file

%prep
%setup -q

%build
export CFLAGS="%optflags -fcommon"
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install
rm -rf %{buildroot}/%{_datadir}/doc

%files
%doc docs/CREDITS ChangeLog.md README.md
%license LICENSE
%{_bindir}/nemesis
%{_mandir}/man1/nemesis*.1%{?ext_man}

%changelog
* Sat Jul 10 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 1.8
  Changes
  * Add automatic IP multicast group to MAC multicast address
    translation
  * Improved usability for composing IGMPv3 reports:
    + Default to 224.0.0.2 for IGMPv3 report type
    + Add -n NUM to control number of group records
  Fixes
  * Fix IGMP v2 join example in README
  * Fix logic for printing DNS protocol: TCP/UDP
  * Fix #12: allow 0.0.0.0 as RIP address
  * Fix #13: multiple definitions of variables
* Wed Jun 10 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.7
  Changes
  * Convert all man pages to mdoc format
  Fixes
  * Fix #6: Skip sleep/delay when sending only one frame,
    i.e. default
  * Fix #9: Call correct exit function in nemesis-dhcp
  * Fix missing S: to getopt() in nemesis-dhcp
  * Fix network byte ordering problem with CIADDR, YIADDR, SIADDR,
    and GIADDR in nemesis-dhcp
  * Fix command line parsing of client MAC address, Ethernet
    source MAC address, and Ethernet destination MAC address in
    nemesis-dhcp
  * Fix missing newline in nemesis-dhcp usage text
  * Fix invalid call to close(), found by Valgrind
* Sun Jun  7 2020 Martin Hauke <mardnh@gmx.de>
- Set CFLAGS+=-fcommon
* Mon Jun 17 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.6
  * Support for DHCP protocol crafting, defaults to DHCP Discover
    with option 53, 12, 60, 61, and 55
  * Support for repeated send in many protocol injectors. Can be
    used to, e.g., flood networks with ARP requests or test DHCP.
  * Incompatible command line option changes to IGMP protocol module
  * Fix invalid IP header length in ICMP packets
* Thu Aug  2 2018 mardnh@gmx.de
- Correct license
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality of description. Remove future goals.
* Mon Jun 18 2018 mardnh@gmx.de
- Initial package, version 1.5
